.. _msumastro_header_processing:

#################
Header processing
#################

************
Introduction
************

The `msumastro.header_processing` subpackage contains classes and functions
that do the work of modifying headers. There are several scripts for
:ref:`automated_scripts` and :ref:`manual_processing` provided to carry out
the most common types of headers processing.

*************
Reference/API
*************

.. automodapi:: msumastro.header_processing.fitskeyword
    :no-inheritance-diagram:

.. automodapi:: msumastro.header_processing.astrometry
    :no-inheritance-diagram:

.. automodapi:: msumastro.header_processing.feder
    :no-inheritance-diagram:

.. automodapi:: msumastro.header_processing.patchers
    :no-inheritance-diagram:
